@@ -12,10 +12,9 @@ from PyQtGuiLib.header import (
     Signal
 )
 
-from PyQtGuiLib.styles import ButtonStyle
-
 '''
-    组件轮播
+    组件轮播 2023.3.7 当前控件的所有功能均处于稳定状态
+    SlideShow 独立版本 3.0
 '''
 class SlideShow(QWidget):
     # 切换窗口事件
@@ -33,7 +32,7 @@ class SlideShow(QWidget):
         #
         self.widgets = []
 
-        self.animation_time = 1000 # 毫秒
+        self.animation_time = 800 # 毫秒
 
         # 动画运行方向,当前动作
         self.ani_direction = (SlideShow.Ani_Left, SlideShow.Ani_Right)
@@ -45,6 +44,10 @@ class SlideShow(QWidget):
         # 窗口索引
         self.index = 0
 
+        # 指向两个当前窗口
+        self.cursor_widget_p = None # type:QWidget
+        self.cursor_widget_p2 = None # type:QWidget
+
         # 创建两侧按钮
         self.createButtons()
 
@@ -60,7 +63,6 @@ class SlideShow(QWidget):
         self.startTimer(interval)
         self.auto_ani_direction = direction_
 
-
     # 左上方向
     def lu_direction(self) -> str:
         return self.ani_direction[0]
@@ -118,7 +120,6 @@ border:2px solid #00557f;
 
     # 移动窗口
     def moveWidget(self,direction_:str):
-
         direction = None
 
         w_1 = self.widgets[self.index]
@@ -138,15 +139,12 @@ border:2px solid #00557f;
             return
 
         w_2 = self.widgets[self.index]
+        self.cursor_widget_p = w_2 # 保存当前窗口
+        self.cursor_widget_p2 = w_1
         self.changeWidget.emit(w_2)# 切换窗口时发送信号
         w_1.show()
         w_2.show()
 
-        # 隐藏其他窗口
-        for w in self.widgets:
-            if w != w_1 and w != w_2:
-                w.hide()
-
         self.ani_(w_1, w_2, direction)
 
     def addWidget(self,widget:QWidget):
@@ -157,6 +155,8 @@ border:2px solid #00557f;
 
         if self.count() > 1:
             widget.hide()
+        else:
+            self.cursor_widget_p = widget
 
     # 设置动作模式
     def setAinDirectionMode(self, mode:tuple):
@@ -174,9 +174,22 @@ border:2px solid #00557f;
     def aniDirection(self) -> tuple:
         return self.ani_direction
 
-    # 移除窗口(只会移除,不会消毁)
+    # 移除窗口
     def removeWidget(self,widget:QWidget):
+        widget.hide()
+        if widget == self.cursor_widget_p:
+            index = self.widgets.index(widget)
+            if index == 0 and self.count() >=1:
+                wid = self.widgets[index+1]
+                wid.resize(self.size())
+                wid.show()
+                self.cursor_widget_p = wid
+            else:
+                self.cursor_widget_p = None
+        if widget == self.cursor_widget_p2:
+            self.cursor_widget_p2 = None
         self.widgets.remove(widget)
+        del widget
 
     # 切换到指定窗口
     def setCurrentIndex(self,index:int=0):
@@ -192,7 +205,6 @@ border:2px solid #00557f;
         for _ in range(abs(n)):
             self.moveWidget(direction)
 
-
     def ani_(self,widget_out:QWidget,widget_show:QWidget,direction:str):
         '''
             widget_out:被移走的窗口
@@ -227,6 +239,9 @@ border:2px solid #00557f;
             s_ani_1,e_ani_1 = QPoint(0,0),QPoint(self.width(),0)
             s_ani_2,e_ani_2 = QPoint(-self.width(),0),QPoint(0,0)
 
+        # 在移出窗口动画完成时,执行隐藏
+        ani_1.finished.connect(lambda :wid1.hide())
+
         ani_1.setStartValue(s_ani_1)
         ani_1.setEndValue(e_ani_1)
 
@@ -251,6 +266,16 @@ border:2px solid #00557f;
         if self.is_auto_slide:
             self.moveWidget(self.auto_ani_direction)
 
+    # 返回当前的窗口
+    def getCursorWidget(self)->QWidget:
+        return self.cursor_widget
+
     def resizeEvent(self, event) -> None:
         self.btnPos()
+        if self.cursor_widget_p:
+            self.cursor_widget_p.resize(self.size())
+            # 窗口大小改变时只显示当前窗口,隐藏其他窗口
+            if self.cursor_widget_p2 and self.cursor_widget_p2.isHidden() is False:
+                self.cursor_widget_p2.hide()
+
         super().resizeEvent(event)
