@@ -1,11 +1,16 @@
 from PyQtGuiLib.header.Qt.qtWidgets import *
 from PyQtGuiLib.header.Qt.qtGui import *
 from PyQtGuiLib.header.Qt.qtCore import *
+from PyQtGuiLib.header.Qt.qtSip import *
+from PyQtGuiLib.header.Qt.qtUic import *
+
 from PyQtGuiLib.header.Qt import qt
 from PyQtGuiLib.header.py.common import *
 
 from PyQtGuiLib.header.versions import PYQT_VERSIONS
-from PyQtGuiLib.header.utility import is_win_sys, is_mac_sys,desktopCenter,desktopSize,textSize
+from PyQtGuiLib.header.utility import *
+from PyQtGuiLib.header.customStyle import CustomStyle
+from PyQtGuiLib.header.error import *
 
 
 # 处理mac下无法运行的情况
